Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(8095)

Unified Diff: components/password_manager/core/browser/password_manager_client.h

Issue 1776673003: Fix the password bubble titles for android. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix the tests Created 4 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/password_manager/core/browser/password_manager_client.h
diff --git a/components/password_manager/core/browser/password_manager_client.h b/components/password_manager/core/browser/password_manager_client.h
index c9c5549aec0d73f413d809425f2d807c1660371c..46485f61e97636cad7048202badd3a751a65582c 100644
--- a/components/password_manager/core/browser/password_manager_client.h
+++ b/components/password_manager/core/browser/password_manager_client.h
@@ -105,11 +105,12 @@ class PasswordManagerClient {
virtual void GeneratePassword();
// Informs the embedder that automatic signing in just happened. The form
// returned to the site is |local_forms[0]|. |local_forms| and
// |federated_forms| contain all the local and federated credentials for the
// site.
virtual void NotifyUserAutoSignin(
- ScopedVector<autofill::PasswordForm> local_forms) = 0;
+ ScopedVector<autofill::PasswordForm> local_forms,
+ const GURL& origin) = 0;
// Inform the embedder that automatic signin would have happened if the user
// had been through the first-run experience to ensure their opt-in. |form|
@@ -105,11 +105,12 @@ class PasswordManagerClient {
virtual void GeneratePassword();
// Informs the embedder that automatic signing in just happened. The form
- // returned to the site is |local_forms[0]|. |local_forms| and
- // |federated_forms| contain all the local and federated credentials for the
- // site.
+ // returned to the site is |local_forms[0]|. |local_forms| contains all the
+ // local credentials for the site. |origin| is a URL of the site the user was
+ // auto signed in to.
virtual void NotifyUserAutoSignin(

Powered by Google App Engine
This is Rietveld 408576698